@@ -1,13 +1,15 @@
 from elf_to_shellcode.elf_to_shellcode.mips.mips import mips_make_shellcode
 from elf_to_shellcode.elf_to_shellcode.intel.x32 import intel_x32_make_shellcode
 from elf_to_shellcode.elf_to_shellcode.intel.x64 import intel_x64_make_shellcode
+from elf_to_shellcode.elf_to_shellcode.arm.x32 import arm_x32_make_shellcode
 
 ENDIANS = ["big", "little"]
 
 shellcode_handlers = {
     "mips": mips_make_shellcode,
     "intel_x32": intel_x32_make_shellcode,
-    "intel_x64": intel_x64_make_shellcode
+    "intel_x64": intel_x64_make_shellcode,
+    "arm_32": arm_x32_make_shellcode
 }
 
 
